# Changelog

<!--next-version-placeholder-->

## v1.0.4 (2021-08-20)
### Fix
* Миграция пропущенная ([`3d54943`](https://github.com/iredun/django-smsru/commit/3d5494351ee6015ab87a230f8100e9030fcb879b))

## v1.0.3 (2021-06-21)


## v1.0.2 (2021-06-21)


## v1.0.1 (2021-06-21)
### Fix
* Ошибки отправки смс ([`3bab696`](https://github.com/iredun/django-smsru/commit/3bab696830406c5852fbf8bdcbd8cfc2aeadd4e3))

## v1.0.0 (2021-03-25)
### Fix
* После отправки вернуть информацию по смс ([`1ac92f2`](https://github.com/iredun/django-smsru/commit/1ac92f29f57e7cff80a0b92f9e2323fefbd65aa5))

### Breaking
* поменялась структура данных возвращаемых после отправки смс  ([`1ac92f2`](https://github.com/iredun/django-smsru/commit/1ac92f29f57e7cff80a0b92f9e2323fefbd65aa5))

## v0.5.0 (2021-03-18)
### Feature
* Получение информации об аккаунте ([`7c9fc00`](https://github.com/iredun/django-smsru/commit/7c9fc00bb7c160d6d90bb50648ef002ee0706904))

### Documentation
* Правка кодировки в CHANGELOG.md ([`cc0656f`](https://github.com/iredun/django-smsru/commit/cc0656fa0560fce6406a4dbe923c01b441cea632))

## v0.4.0 (2021-01-19)
### Feature
* Signals ([`184dca9`](https://github.com/iredun/django-smsru/commit/184dca9b641c1d47e85e7a9ad49cdde4f98144b6))

### Fix
* Sms_callback ([`dabf6f3`](https://github.com/iredun/django-smsru/commit/dabf6f3c498f41218e3120bf9116d19f20527a1f))

## v0.3.0 (2021-01-19)
### Feature
* Отправка на несколько номеров ([`6bc3c69`](https://github.com/iredun/django-smsru/commit/6bc3c69bffbb63056fb884277793c894592c9142))

### Fix
* Актуализация перевода ([`ece1351`](https://github.com/iredun/django-smsru/commit/ece13518b1ac0a141d6fffcfda9229a704659d85))

## v0.2.5 (2021-01-19)
### Fix
* Setup.cfg README.md ([`fb08a2b`](https://github.com/iredun/django-smsru/commit/fb08a2bfadd3287604c701d967e125b7a5d0691e))

## v0.2.4 (2021-01-19)
### Fix
* Setup.cfg ([`0bc9d57`](https://github.com/iredun/django-smsru/commit/0bc9d579340ba0f14684b2e76ebe86c8c2635931))

## v0.2.3 (2021-01-19)
### Fix
* Gitignore + CHANGELOG.md ([`b1f0cc8`](https://github.com/iredun/django-smsru/commit/b1f0cc81183c3fda1f204664eac234db8ab71d74))

## v0.2.2 (2021-01-19)
### Fix
* Вернул билд ([`7c23858`](https://github.com/iredun/django-smsru/commit/7c23858c044768c7f7119876fbf5c79ed9e884d6))

## v0.2.0 (2021-01-19)
### Feature
* Стартовый набор ([`96c124f`](https://github.com/iredun/django-smsru/commit/96c124f4377da825491cc14eefc63ce0efaa728c))

### Fix
* Настройка semantic_release ([`5d15a5c`](https://github.com/iredun/django-smsru/commit/5d15a5cede968428dae0bd775316dcf6779554b8))
* Настройка setup tool ([`6348491`](https://github.com/iredun/django-smsru/commit/6348491c76f5d5aa83ad3057071831140d19b853))